@@ -9,11 +9,14 @@ from .. import requirePackage
 
 
 class QiniuOSS:
-    qiniu = requirePackage('qiniu')
+    qiniu = requirePackage("qiniu")
 
-    def __init__(self, ac_key: str = pre_check('qiniu_ac_key'),
-                 sc_key: str = pre_check('qiniu_sc_key'),
-                 df_bucket: str = pre_check('qiniu_bk_name')):
+    def __init__(
+        self,
+        ac_key: str = pre_check("qiniu_ac_key"),
+        sc_key: str = pre_check("qiniu_sc_key"),
+        df_bucket: str = pre_check("qiniu_bk_name"),
+    ):
         """
         初始化并登陆七牛云对象存储
 
@@ -38,11 +41,11 @@ class QiniuOSS:
         :return: 函数表
         """
         return {
-            '-up': self.upload,
-            '-rm': self.remove,
-            '-cp': self.copy_url,
-            '-dl': self.download,
-            '-ls': self.list_bucket
+            "-up": self.upload,
+            "-rm": self.remove,
+            "-cp": self.copy_url,
+            "-dl": self.download,
+            "-ls": self.list_bucket,
         }
 
     def upload(self, filePath: str, bucket: str = None):
@@ -56,20 +59,28 @@ class QiniuOSS:
         :return: None
         """
         import os
+
         filename = os.path.basename(filePath)
 
         def progress(cur, total):
             if not self.bar:
                 from ..TuiTools.Bar import DataTransformBar
+
                 self.bar = DataTransformBar()
-                self.tid = self.bar.add_task('Transform' if user_lang != 'zh' else '传输', filename=filename, total=total)
+                self.tid = self.bar.add_task(
+                    "Transform" if user_lang != "zh" else "传输",
+                    filename=filename,
+                    total=total,
+                )
                 self.bar.start()
                 self.bar.start_task(self.tid)
             self.bar.update(self.tid, completed=cur)
 
         filePath = filePath.strip()
         tk = self.auth.upload_token(bucket if bucket else self.df_bucket, filePath)
-        QiniuOSS.qiniu.put_file(tk, filePath.replace(dir_char, '/'), filePath, progress_handler=progress)
+        QiniuOSS.qiniu.put_file(
+            tk, filePath.replace(dir_char, "/"), filePath, progress_handler=progress
+        )
         self.bar.stop()
 
     def remove(self, filePath: str, bucket: str = None):
@@ -96,7 +107,9 @@ class QiniuOSS:
         :return: None
         """
         bk = QiniuOSS.qiniu.BucketManager(self.auth)
-        bk.fetch(filePath, bucket if bucket else self.df_bucket, filePath.split('/')[-1])
+        bk.fetch(
+            filePath, bucket if bucket else self.df_bucket, filePath.split("/")[-1]
+        )
 
     def get_bucket_url(self, bucket: str = None):
         """
@@ -108,12 +121,16 @@ class QiniuOSS:
         :return: 成功返回json，否则False
         """
         import requests
+
         bucket = bucket if bucket else self.df_bucket
-        url = 'http://api.qiniu.com/v6/domain/list?tbl=%s' % bucket
-        res = requests.get(url, headers={
-            "Content-Type": "application/x-www-form-urlencoded",
-            "Authorization": "QBox %s" % self.auth.token_of_request(url)
-        })
+        url = "http://api.qiniu.com/v6/domain/list?tbl=%s" % bucket
+        res = requests.get(
+            url,
+            headers={
+                "Content-Type": "application/x-www-form-urlencoded",
+                "Authorization": "QBox %s" % self.auth.token_of_request(url),
+            },
+        )
         if res.status_code == requests.codes.ok:
             return res.json()
         else:
@@ -131,18 +148,27 @@ class QiniuOSS:
         from .. import qs_default_console, qs_info_string
         from ..TuiTools.Table import qs_default_table
         from rich.text import Text
+
         bk = QiniuOSS.qiniu.BucketManager(self.auth)
         ret = bk.list(bucket if bucket else self.df_bucket)
         if not ret[1]:
-            print("ERROR!" if user_lang != 'zh' else '错误!')
+            print("ERROR!" if user_lang != "zh" else "错误!")
             exit(0)
-        root_url = 'http://' + self.get_bucket_url(bucket)[0] + '/'
-        ret = ret[0]['items']
+        root_url = "http://" + self.get_bucket_url(bucket)[0] + "/"
+        ret = ret[0]["items"]
         from ..NetTools.NormalDL import size_format
-        tb = qs_default_table(['File', 'Size'] if user_lang != 'zh' else ['文件', '体积'], title='七牛 OSS')
+
+        tb = qs_default_table(
+            ["File", "Size"] if user_lang != "zh" else ["文件", "体积"], title="七牛 OSS"
+        )
         for i in ret:
-            tb.add_row(Text(i['key'], justify="left"), Text(size_format(i['fsize'], True), justify='right'))
-        qs_default_console.print(qs_info_string, "Bucket url:" if user_lang != 'zh' else '桶链接:', root_url)
+            tb.add_row(
+                Text(i["key"], justify="left"),
+                Text(size_format(i["fsize"], True), justify="right"),
+            )
+        qs_default_console.print(
+            qs_info_string, "Bucket url:" if user_lang != "zh" else "桶链接:", root_url
+        )
         qs_default_console.print(tb, justify="center")
 
     def download(self, filePath: str, bucket: str = None):
@@ -156,13 +182,14 @@ class QiniuOSS:
         :return: None
         """
         from ..NetTools.NormalDL import normal_dl
+
         bucket = bucket if bucket else self.df_bucket
         root_url = self.get_bucket_url(bucket)[0]
         if root_url:
-            root_url = 'http://' + root_url + '/'
+            root_url = "http://" + root_url + "/"
         else:
-            exit('Get Bucket Url Failed!' if user_lang != 'zh' else '获取桶链接失败!')
+            exit("Get Bucket Url Failed!" if user_lang != "zh" else "获取桶链接失败!")
         dl_url = root_url + filePath
-        if bucket.startswith('admin'):
+        if bucket.startswith("admin"):
             dl_url = self.auth.private_download_url(dl_url)
         normal_dl(dl_url)
